@@ -14,8 +14,7 @@ import os, shutil, string, sys, time
 class Mooi:
 	DIR = os.path.expandvars('${HOME}/Lavengro')
 	LRC = os.path.expandvars(DIR + os.sep + 'lavengrorc')
-	HDR = "\n\nLavengro - The Word Master\n\n" 
-	SUB =  "(Available subjects)"
+	HDR = "\n\nLavengro - The Word Master" 
 	MODE = ['lavengro - programmed learning',
 			'test - one chance to answer, scored result',
 			'tutor - retest until all correct, no score',
@@ -60,7 +59,7 @@ class Mooi:
 
 	# get user to choose an element from thing
 	def query(self, thing, prompt):
-		print "\n\n--- 'q' to quit ---"
+		print "\n--- 'q' to quit ---"
 		length = len(thing)
 		choice = length + 1
 		for i in range(0, length):
@@ -143,7 +142,6 @@ class Mooi:
 				if ((os.path.isdir(self.DIR + os.sep + file)) and
 					(file != 'py')):
 					dirs.append(file)
-			print self.SUB
 			self.subject = choice = self.query(dirs, 'Choose subject: ')
 			self.subdir = dirs[choice]
 		# set testing mode
